
## @knitr affy
## Download der Funktion biocLite bzw. des Paketes "BiocInstaller"
source("http://bioconductor.org/biocLite.R")
## Alternativ: Laden des Paket "BiocInstaller"
library(BiocInstaller)

## Installation der Pakete "affy", "affydata" und "hgu133acdf"
biocLite(c("affy", "affydata", "hgu133acdf"))


## @knitr affydata
## Laden der notwendigen Pakete
library(affy)
library(affydata)
library(hgu133acdf)


## @knitr ReadAffy
## Pfad zu den Daten
Pfad.affydata <- system.file("celfiles", package="affydata")
## Auflistung der CEL-Dateien
Dateien.affydata <- list.celfiles(path=Pfad.affydata, full.names=TRUE)
## Einlesen einer CEL-Datei
Daten.affy <- ReadAffy(filenames=Dateien.affydata[1])
Daten.affy


## @knitr eSet
## Informationen zur Klasse "eSet"
getClass("eSet")


## @knitr lumi
## Installation der Pakete
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite(c("lumi", "lumiHumanAll.db"))


## @knitr lumiHuman
## Laden der Pakete
library(lumi)
library(lumiHumanAll.db)


## @knitr download.file
## Link
Link <- "http://www.switchtoi.com/datasets/tumoradjacent/"
## Name der zip-Datei
Dateiname <- "TumorAdjacent_BeadStudioOutput.zip"
## Zusammenfügen von Link und Dateiname
URL <- paste(Link, Dateiname, sep="")

## Download der zip-Datei (ca. 16 MByte)
download.file(url = URL, destfile = Dateiname)

## Extraktion der Datei "TumorAdjacent-probe-raw.txt"
unzip(zipfile = Dateiname, files = "TumorAdjacent-probe-raw.txt")


## @knitr lumiR
## Einlesen von "TumorAdjacent-probe-raw.txt" - ohne QC
Daten.lumi <- lumiR(file = "TumorAdjacent-probe-raw.txt", QC = FALSE)
Daten.lumi


## @knitr lumiBatch
## Informationen zur Klasse "LumiBatch"
getClass("LumiBatch")


## @knitr beadarray
## Installation der Pakete
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite(c("beadarray", "illuminaHumanv2.db"))


## @knitr illuminaHuman
## Laden der Pakete
library(beadarray)
library(illuminaHumanv2.db)


## @knitr readBeadSummaryData
## Einlesen von "TumorAdjacent-probe-raw.txt"
BSDaten <- readBeadSummaryData(dataFile = "TumorAdjacent-probe-raw.txt",
                               skip = 0,
                               illuminaAnnotation = "Humanv2")
BSDaten


## @knitr ExpressionSetIllumina
## Informationen zur Klasse "ExpressionSetIllumina"
getClass("ExpressionSetIllumina")


## @knitr BeadArrayUseCases
## Installation der Pakete
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite(c("BeadArrayUseCases", "illuminaHumanv3.db"))


## @knitr illuminaHumanv3
## Laden der Annotation
library(illuminaHumanv3.db)


## @knitr readIllumina
## Pfad zu den Dateien
Pfad <- system.file("extdata/Chips", package = "BeadArrayUseCases")
## Auflistung der Dateien
Dateien <- list.files(Pfad, full.names = TRUE)

## Einlesen der Bead-Level-Daten ohne Verwendung der Bilddateien
BLDaten <- readIllumina(dir = Pfad, sampleSheet = Dateien[13], 
                        useImages = FALSE, 
                        illuminaAnnotation = "Humanv3" )
BLDaten


## @knitr beadLevelData
## Informationen zur Klasse "beadLevelData"
getClass("beadLevelData")


## @knitr marray
## Installation des Paketes
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite("marray")


## @knitr marray1
## Laden des Paketes
library(marray)


## @knitr read.marrayInfo
## Pfad zu den Dateien
Pfad <- system.file("swirldata", package = "marray")
## Auflistung der Dateien
Dateien <- list.files(Pfad, full.names = TRUE)

## Einlesen der Informationen zum Experiment
Exp.Infos <- read.marrayInfo(Dateien[6])
## Ausgabe einer Übersicht
summary(Exp.Infos)


## @knitr marrayInfo
## Informationen zur Klasse "marrayInfo"
getClass("marrayInfo")


## @knitr read.Galfile
## Einlesen der Gal-Datei
Array.Infos <- read.Galfile("fish.gal", path = Pfad)
summary(Array.Infos)
## Übersicht zum Array-Layout
summary(Array.Infos$layout)
## Übersicht zur Annotation
summary(Array.Infos$gnames)


## @knitr marrayLayout
## Informationen zur Klasse "marrayLayout"
getClass("marrayLayout")


## @knitr read.Spot
## Einlesen der Daten
Daten.marray <- read.Spot(path = Pfad, 
                          layout = Array.Infos$layout,
                          gnames = Array.Infos$gnames,
                          target = Exp.Infos)
## Ausgabe einer Übersicht
summary(Daten.marray)


## @knitr read.Spot1
## Ausgabe einer Übersicht
summary(Daten.marray)


## @knitr marray2
## Informationen zur Klasse "marrayRaw"
getClass("marrayRaw")


## @knitr marrayInput
## Zeige Vignetten an
vignette("marrayClasses")
vignette("marrayClassesShort")
vignette("marrayInput")


## @knitr limma
## Installation des Paketes
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite("limma")


## @knitr limma1
## Laden des Paketes
library(limma)


## @knitr readTargets
## Einlesen der Informationen zum Experiment
Infos <- readTargets(file=Dateien[6])
Infos


## @knitr read.maimages
## Einlesen der Daten
RG <- read.maimages(Infos$Names, path = Pfad, source="spot")
RG


## @knitr read.maimages1
RG


## @knitr RGList
## Informationen zur Klasse "RGList"
getClass("RGList")


## @knitr limma2
## Informationen zur Klasse "EListRaw"
getClass("EListRaw")


## @knitr limmaUserGuide
## Aufruf der Dokumentation zu limma
limmaUserGuide()


