
## @knitr RobLoxBioC
## Installation des Paketes
install.packages("RobLoxBioC", repos = "http://cran.at.r-project.org")


## @knitr RobLoxBioC1
## Laden der Pakete
library(affy)
library(affydata)
library(RobLoxBioC)
## Laden des Datensatzes
data(Dilution)


## @knitr MAS5
## Vorverarbeitung mit Variante von MAS 5.0
eset.mas5 <- robloxbioc(Dilution, normalize = TRUE)


## @knitr rma
## Vorverarbeitung mit RMA
eset.rma <- rma(Dilution)


## @knitr gcrma
## Installation des Paketes
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite("gcrma")


## @knitr gcrma1
## Lade das Paket
library(gcrma)


## @knitr gcrma2
## Vorverarbeitung mit GCRMA
eset.gcrma <- gcrma(Dilution)


## @knitr plier
## Installation des Paketes
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite("plier")


## @knitr plier1
## Laden des Paketes
library(plier)


## @knitr plier2
## Vorverabeitung mit PLIER und Quantilnormalisierung
eset.plier <- justPlier(Dilution, normalize = TRUE)


## @knitr vsn
## Installation des Paketes
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite("vsn")


## @knitr vsn1
## Laden des Paketes
library(vsn)


## @knitr vsn2
## Vorverarbeitung mit VSN
eset.vsn <- expresso(Dilution, bg.correct = FALSE, 
                     normalize.method = "vsn",
                     ## verwende nur PM-Werte
                     pmcorrect.method = "pmonly",
                     ## Aggregation mittels Median
                     summary.method = "avgdiff")


## @knitr vsnrma
## Vorverabeitung mit VSN und RMA
eset.vsnrma <- vsnrma(Dilution)


## @knitr boxplots
## Teile Graphikfenster in 2 Zeilen und 3 Spalten
par(mfrow = c(2, 3))
## Erzeuge die Boxplots
boxplot(log2(exprs(eset.mas5)), main = "MAS 5.0")
boxplot(exprs(eset.rma), main = "RMA")
boxplot(exprs(eset.gcrma), main = "GCRMA")
boxplot(exprs(eset.plier), main = "PLIER")
boxplot(log2(exprs(eset.vsn)), main = "VSN")
boxplot(exprs(eset.vsnrma), main = "VSNRMA")


## @knitr meanSdPlots
## Teile Graphikfenster in 2 Zeilen und 3 Spalten
par(mfrow = c(2, 3))
## Erzeuge die Mittelwert-SD-Plots mit einheitlicher y-Aches (ylim)
meanSdPlot(log2(exprs(eset.mas5)), main = "MAS 5.0", ylim = c(0,1))
meanSdPlot(exprs(eset.rma), main = "RMA", ylim = c(0,1))
meanSdPlot(exprs(eset.gcrma), main = "GCRMA", ylim = c(0,1))
meanSdPlot(exprs(eset.plier), main = "PLIER", ylim = c(0,1))
meanSdPlot(log2(exprs(eset.vsn)), main = "VSN", ylim = c(0,1))
meanSdPlot(exprs(eset.vsnrma), main = "VSNRMA", ylim = c(0,1))


## @knitr cors
## Berechnung der Pearson-Korrelationen 
## MAS 5.0
cor.mas5 <- cor(log2(exprs(eset.mas5)))
## RMA
cor.rma <- cor(log2(exprs(eset.rma)))
## GCRMA
cor.gcrma <- cor(exprs(eset.gcrma))
## PLIER
cor.plier <- cor(exprs(eset.plier))
## VSN
cor.vsn <- cor(log2(exprs(eset.vsn)))
## VSNRMA
cor.vsnrma <- cor(exprs(eset.vsnrma))

## Auswahl der relevanten Korrelationen
ausw <- lower.tri(cor.mas5, diag = FALSE)
Korrelationen <- data.frame("MAS 5.0" = cor.mas5[ausw],
                            "RMA" = cor.rma[ausw],
                            "GCRMA" = cor.gcrma[ausw],
                            "PLIER" = cor.plier[ausw],
                            "VSN" = cor.vsn[ausw],
                            "VSNRMA" = cor.vsnrma[ausw])
## Kompakte Ausgabe der relevanten Korrelationen
round(Korrelationen, 3)


## @knitr genefilter
## Installation des Paketes
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite("genefilter")


## @knitr genefilter1
## Laden des Paketes
library(genefilter)


## @knitr dists
## Berechung der mittleren L1-Abstände
## MAS 5.0
dist2.mas5 <- dist2(log2(exprs(eset.mas5)))
## RMA
dist2.rma <- dist2(exprs(eset.rma))
## GCRMA
dist2.gcrma <- dist2(exprs(eset.gcrma))
## PLIER
dist2.plier <- dist2(exprs(eset.plier))
## VSN
dist2.vsn <- dist2(log2(exprs(eset.vsn)))
## VSNRMA
dist2.vsnrma <- dist2(exprs(eset.vsnrma))

## Auswahl der relevanten Abstände
ausw <- lower.tri(dist2.mas5, diag = FALSE)
L1.Abstände <- data.frame("MAS 5.0" = dist2.mas5[ausw],
                          "RMA" = dist2.rma[ausw],
                          "GCRMA" = dist2.gcrma[ausw],
                          "PLIER" = dist2.plier[ausw],
                          "VSN" = dist2.vsn[ausw],
                          "VSNRMA" = dist2.vsnrma[ausw])
## Kompakte Ausgabe der relevanten Abstände
round(L1.Abstände, 3)


