
## @knitr swirlPrepro
## Laden der Pakete
library(limma)
library(marray)
library(convert)
## Laden des Datensatzes
data(swirl)


## @knitr backgroundCorrect
## Konvertierung marrayRaw -> RGList
swirl.RG <- as(swirl, "RGList")
## Subtraktion der Hintergrund-Signalintensitäten
swirl.subtract <- backgroundCorrect(swirl.RG, method = "subtract")
## Anwendung der Methode "normexp"
swirl.normexp <- backgroundCorrect(swirl.RG, method = "normexp")


## @knitr backgroundCorrect-boxplots
## Teile Graphikfenster in 2 Zeilen und 3 Spalten
par(mfrow = c(2,3))
## Erzeuge die Boxplots
boxplot(swirl.RG$G, log = "y", las = 2,
        main = "Vordergrund grün - unkorregiert",
        names = maLabels(maTargets(swirl)), ylim = c(0.001,50000))
boxplot(swirl.subtract$G, log = "y", las = 2,
        main = "Vordergrund grün - subtract",
        names = maLabels(maTargets(swirl)), ylim = c(0.001,50000))
boxplot(swirl.normexp$G, log = "y", las = 2,
        main = "Vordergrund grün - normexp",
        names = maLabels(maTargets(swirl)), ylim = c(0.001,50000))
boxplot(swirl.RG$R, log = "y", las = 2,
        main = "Vordergrund rot - unkorregiert",
        names = maLabels(maTargets(swirl)), ylim = c(0.001,50000))
boxplot(swirl.subtract$R, log = "y", las = 2,
        main = "Vordergrund rot - subtract",
        names = maLabels(maTargets(swirl)), ylim = c(0.001,50000))
boxplot(swirl.normexp$R, log = "y", las = 2,
        main = "Vordergrund rot - normexp",
        names = maLabels(maTargets(swirl)), ylim = c(0.001,50000))


## @knitr maNorm
## Zentrierung am Median
swirl.global <- maNorm(as(swirl.subtract, "marrayRaw"), norm = "median")
## Skalierung mit dem MAD
swirl.global <- maNormScale(swirl.global, norm = "globalMAD")
## loess Normalisierung
swirl.loess <- maNormMain(as(swirl.subtract, "marrayRaw"))


## @knitr normalizeWithinArrays
## robustspline Normalisierung - alle Arrays einzeln
swirl.robustspline <- normalizeWithinArrays(swirl.subtract, 
                                            method = "robustspline",
                                            bc.method = "none")


## @knitr normalizeBetweenArrays
## quantile Normalisierung - alle Arrays zusammen
swirl.quantile <- normalizeBetweenArrays(swirl.subtract,
                                         method = "quantile")


## @knitr vsnAndere
## Laden des Paketes
library(vsn)


## @knitr normalizeVSN
## VSN Normalisierung
swirl.vsn <- normalizeVSN(swirl.RG)


## @knitr boxplotsPreproAndere
## Teile Graphikfenster in 2 Zeilen und 3 Spalten
par(mfrow = c(2,3))
## Erzeuge die Boxplots
boxplot(as(swirl.subtract, "marrayRaw"), yvar="maM", main="Subtraktion", 
        ylim = c(-4, 4), names = maLabels(maTargets(swirl)), las = 2)
boxplot(swirl.global, yvar="maM", main="Median und MAD", 
        ylim = c(-4, 4), names = maLabels(maTargets(swirl)), las = 2)
boxplot(swirl.loess, yvar="maM", main="loess", ylim = c(-4, 4),
        names = maLabels(maTargets(swirl)), las = 2)
boxplot(as(swirl.robustspline, "marrayNorm"), yvar="maM", main="robustspline", 
        ylim = c(-4, 4), names = maLabels(maTargets(swirl)), las = 2)
boxplot(as(swirl.quantile, "marrayNorm"), yvar="maM", main="quantile", 
        ylim = c(-4, 4), names = maLabels(maTargets(swirl)), las = 2)
boxplot(as(swirl.vsn, "marrayNorm"), yvar="maM", main="VSN", 
        ylim = c(-4, 4), names = maLabels(maTargets(swirl)), las = 2)


## @knitr meanSdPlotsAndere
## Teile Graphikfenster in 2 Zeilen und 3 Spalten
par(mfrow = c(2,3))
## Erzeuge die Mittelwert-SD-Plots
meanSdPlot(MA.RG(swirl.subtract)$M, ylim = c(0, 2), main = "Subtraktion")
meanSdPlot(as(swirl.global, "MAList")$M, ylim = c(0, 2), 
           main = "Median und MAD")
meanSdPlot(as(swirl.loess, "MAList")$M, ylim = c(0, 2), main = "loess")
meanSdPlot(swirl.robustspline$M, ylim = c(0, 2), main = "robustspline")
meanSdPlot(swirl.quantile$M, ylim = c(0, 2), main = "quantile")
meanSdPlot(swirl.vsn$M, ylim = c(0, 2), main = "VSN")


## @knitr corsAndere
## Berechnung der Pearson-Korrelationen
## Subtraktion der Hintergrundsignale
cor.subtract <- cor(MA.RG(swirl.subtract)$M)
## Median und MAD
cor.global <- cor(as(swirl.global, "MAList")$M)
## loess
cor.loess <- cor(as(swirl.loess, "MAList")$M)
## robustspline
cor.robustspline <- cor(swirl.robustspline$M)
## Quantil
cor.quantile <- cor(swirl.quantile$M)
## VSN
cor.vsn <- cor(swirl.vsn$M)

## Auswahl der relevanten Korrelationen
ausw <- lower.tri(cor.subtract, diag = FALSE)
Korrelationen <- data.frame("Subtraktion" = cor.subtract[ausw],
                            "Median und MAD" = cor.global[ausw],
                            "loess" = cor.loess[ausw],
                            "robustspline" = cor.robustspline[ausw],
                            "quantile" = cor.quantile[ausw],
                            "VSN" = cor.vsn[ausw])
## Kompakte Ausgabe der relevanten Korrelationen
round(Korrelationen, 3)


## @knitr genefilterAndere
## Laden des Paketes
library(genefilter)


## @knitr distsAndere
## Berechung der mittleren L1-Abstände
## Subtraktion der Hintergrundsignale
dist2.subtract <- dist2(MA.RG(swirl.subtract)$M)
## Median und MAD
dist2.global <- dist2(as(swirl.global, "MAList")$M)
## loess
dist2.loess <- dist2(as(swirl.loess, "MAList")$M)
## robustspline
dist2.robustspline <- dist2(swirl.robustspline$M)
## Quantil
dist2.quantile <- dist2(swirl.quantile$M)
## VSN
dist2.vsn <- dist2(swirl.vsn$M)

## Auswahl der relevanten L1-Abstände
ausw <- lower.tri(dist2.subtract, diag = FALSE)
L1.Abstände <- data.frame("Subtraktion" = dist2.subtract[ausw],
                          "Median und MAD" = dist2.global[ausw],
                          "loess" = dist2.loess[ausw],
                          "robustspline" = dist2.robustspline[ausw],
                          "quantile" = dist2.quantile[ausw],
                          "VSN" = dist2.vsn[ausw])
## Kompakte Ausgabe der relevanten L1-Abstände
round(L1.Abstände, 3)


